# pyvitemadose

pyvitemadose displays available chronodoses of covid vaccine for your departement in France

## install

``pip3 install pyvitemadose``
or
``pip install pyvitemadose``

## use

pyvitemadose \[DPT\] with DPT the department

example : ``pyvitemadose 75`` to display chronodose availables in dpt 75


## update 

``pyvitemadose -u``

## exit code

the exit code is 0 if chronodose are available, 2 otherwise
